@@ -69,6 +69,13 @@ weights = [1]
 # If not exporting indices with composites to save space, medoid should be used
 compositingMethod = 'medoid'
 
+# Choose which Landsat USGS Collection version to use
+# Choices are 'C1' for Collection 1 and 'C2' for Collection 2
+# Only choose 'C1' if working with other Collection 1 data and using
+# data from before 1/1/2022. Otherwise, choose 'C2'
+# See: https://www.usgs.gov/landsat-missions/landsat-collection-2 for more information
+landsatCollectionVersion = 'C1'
+
 # Choose Top of Atmospheric (TOA) or Surface Reflectance (SR)
 # Use caution when combining Landsat and S2 SR data since S2 SR data had terrain correction performed 
 toaOrSR = 'TOA'
@@ -252,7 +259,7 @@ processedAndComposites = getImagesLib.getLandsatAndSentinel2HybridWrapper(studyA
   False,250,
   exportComposites,outputName,exportPathRoot,crs,transform,scale,
   preComputedLandsatCloudScoreOffset,preComputedLandsatTDOMIRMean,preComputedLandsatTDOMIRStdDev,preComputedSentinel2CloudScoreOffset,preComputedSentinel2TDOMIRMean,preComputedSentinel2TDOMIRStdDev,
-  cloudProbThresh);
+  cloudProbThresh,landsatCollectionVersion);
 
 #Separate into scenes and composites for subsequent analysis
 processedScenes = processedAndComposites['processedScenes']
